Oh My Tools
===================


Features
-------------------
* easy to extent
* easy integration
* ui
* interactively

Installation
-------------------
```
pip install omc
omc config init
```






